| Title: | Programmatic Access to Bank for International Settlements Data |
|---|---|
| Description: | Provides an interface to data provided by the Bank for International Settlements <https://www.bis.org>, allowing for programmatic retrieval of a large quantity of (central) banking data. |
| Authors: | Stefan Angrick [aut, cre], Eric Persson [aut] |
| Maintainer: | Stefan Angrick <[email protected]> |
| License: | CC0 |
| Version: | 0.4 |
| Built: | 2026-05-12 05:56:01 UTC |
| Source: | https://github.com/cran/BIS |
Download and parse a BIS data set
get_bis(item_url, ...)get_bis(item_url, ...)
item_url |
Character. URL of the data set to be imported (usually
obtained via |
... |
Arguments passed to |
A tibble data frame.
ds <- get_datasets() df <- get_bis(ds$url[ds$id == "WS_CBPOL_csv_flat"])ds <- get_datasets() df <- get_bis(ds$url[ds$id == "WS_CBPOL_csv_flat"])
Retrieve a list of available BIS data sets
get_datasets(base_url = "https://data.bis.org/bulkdownload")get_datasets(base_url = "https://data.bis.org/bulkdownload")
base_url |
Character. URL of the BIS's homepage listing single file data sets for download (optional). |
A tibble data frame.
ds <- get_datasets()ds <- get_datasets()
Read a BIS data set from a local file
read_bis(file_path)read_bis(file_path)
file_path |
Character. Path to the CSV file to be read (usually obtained via manual download from the BIS homepage). |
A tibble data frame.
## Not run: # Example 1: Read a locally stored CSV df <- read_bis("WS_CBPOL_csv_flat.csv") # Example 2: Read a locally stored ZIP df <- read_bis(.unzip_file("WS_CBPOL_csv_flat.zip")) ## End(Not run)## Not run: # Example 1: Read a locally stored CSV df <- read_bis("WS_CBPOL_csv_flat.csv") # Example 2: Read a locally stored ZIP df <- read_bis(.unzip_file("WS_CBPOL_csv_flat.zip")) ## End(Not run)